@@ -4,27 +4,32 @@
 
 (autoload 'custom-add-loads "cus-load")
 
-(custom-add-loads 'hypermedia '("htmlize"))
-(custom-add-loads 'hexl '("hexl"))
-(custom-add-loads 'languages '("crontab" "winmgr-mode" "xrdb-mode"))
-(custom-add-loads 'rtf '("rtf-support"))
-(custom-add-loads 'matching '("whitespace-mode"))
-(custom-add-loads 'processes '("ansi-color" "flyspell"))
-(custom-add-loads 'flyspell '("flyspell"))
-(custom-add-loads 'winmgr '("winmgr-mode"))
-(custom-add-loads 'xrdb '("xrdb-mode"))
-(custom-add-loads 'ansi-colors '("ansi-color"))
-(custom-add-loads 'htmlize '("htmlize"))
-(custom-add-loads 'whitespace '("whitespace-mode"))
-(custom-add-loads 'fill '("filladapt"))
-(custom-add-loads 'data '("hexl"))
-(custom-add-loads 'outlines '("whitespace-mode"))
-(custom-add-loads 'folding '("folding"))
-(custom-add-loads 'wp '("rtf-support" "scribe"))
-(custom-add-loads 'scribe '("scribe"))
 (custom-add-loads 'filladapt '("filladapt"))
+(custom-add-loads 'apache '("auto-autoloads" "apache-mode"))
+(custom-add-loads 'rtf '("rtf-support"))
+(custom-add-loads 'xrdb '("xrdb-mode"))
+(custom-add-loads 'ispell '("flyspell"))
 (custom-add-loads 'tools '("autoinsert" "folding"))
-(custom-add-loads 'auto-insert '("autoinsert"))
+(custom-add-loads 'hypermedia '("css-mode" "htmlize"))
+(custom-add-loads 'css '("css-mode"))
+(custom-add-loads 'outlines '("whitespace-mode"))
+(custom-add-loads 'hexl '("hexl"))
+(custom-add-loads 'data '("hexl"))
 (custom-add-loads 'crontab '("crontab"))
+(custom-add-loads 'ansi-colors '("ansi-color"))
+(custom-add-loads 'scribe '("scribe"))
+(custom-add-loads 'auto-insert '("autoinsert"))
+(custom-add-loads 'htmlize '("htmlize"))
+(custom-add-loads 'flyspell '("flyspell"))
+(custom-add-loads 'languages '("auto-autoloads" "crontab" "css-mode" "winmgr-mode" "xrdb-mode"))
+(custom-add-loads 'fill '("filladapt"))
+(custom-add-loads 'folding '("folding"))
+(custom-add-loads 'processes '("ansi-color" "flyspell"))
+(custom-add-loads 'wp '("rtf-support" "scribe"))
+(custom-add-loads 'po '("po-mode"))
+(custom-add-loads 'whitespace '("whitespace-mode"))
+(custom-add-loads 'matching '("whitespace-mode"))
+(custom-add-loads 'winmgr '("winmgr-mode"))
+(custom-add-loads 'i18n '("po-mode"))
 
 ;;; custom-load.el ends here
